from dataclasses import dataclass
from d_tool import d_management_display
from Stilix_data_change import empty_list
@dataclass
class ladder_:
          ladder_design_storage: list[str]
          def set_amount(self,amount: int,list_: list):
                    list_.append(amount)
          
LADDER_ = ladder_(["-"])

class ladder_hewn_:
                    
          def design_ladder(self,amount: int):
                    while amount > 0:
                              print(LADDER_.ladder_design_storage[0])
                              amount -= 1

          def ladder_amount(self,amount_of_ladder: list[int]):
                    d_management_display.store_(True,amount_of_ladder[0])
          
          def change_ladder_style(self,desired_style: any):
                    LADDER_.ladder_design_storage[0] = desired_style

LADDER_HEWN_ = ladder_hewn_()

'''
The LADDER_HEWN_ object manages further output.Ladder hewn inserts design between two text.

text 1
-
-
-
text 2

The LADDER_ object contains the default - symbol which is used to print a desired amount of it between two pieces of text.The design_ladder method of LADDER_HEWN_can be used to print a desired amount of - symbols.
The ladder_amount method of the LADDER_HEWN_ object displays the amount of -s printed but the list containing the amount should be put in the brackets when your calling the method.LADDER_HEWN_.ladder_amount(list containing amount).
The amount can be stored by the LADDER_.set_amount method in your desired list.Dont want to use -s , you can use the LADDER_HEWN_.change_ladder_style method to change to your desired style

a = []
LADDER_.set_amount(1,a)
LADDER_HEWN_.change_ladder_style("w")
LADDER_HEWN_.design_ladder(a[0])
LADDER_HEWN_.ladder_amount(a)

w
1
'''




from Stilix import STILIX_LIST
from dataclasses import dataclass

@dataclass
class extra_layer:
          extra_layer_storage: list[list]
          def add_layers(self,layers_amount: int):
                    while layers_amount > 0:
                              STILIX_LIST.add_styles(self.extra_layer_storage,[[]])
                              layers_amount -= 1
          
          def remove_layers(self,layers_to_remove_amount: int):
                    while layers_to_remove_amount > 0:
                              STILIX_LIST.remove_styles(self.extra_layer_storage,[[]])
                              layers_to_remove_amount -= 1
                              
          def display_layers(self):
                    STILIX_LIST.display_all(self.extra_layer_storage)
          
          def display_layers_horizontal(self):
                    STILIX_LIST.display_all_horizontal(self.extra_layer_storage)
                    
EXTRA_LAYER = extra_layer([])

'''
The EXTRA_LAYER object can be used to make multiple empty lists.Each empty list can be assigned to manage one task.The add_layers method can be used to add a desired amount of empty lists to EXTRA_LAYER.extra_layer_storage.
The remove layers method can be used to remove a desired amount of empty lists from EXTRA_LAYER.extra_layer_storage.The display_layers method can be used to display the empty lists vertically.The display_layers_horizontal
method can be used to display the empty lists horizontally.

EXTRA_LAYER.add_layers(3)

print(EXTRA_LAYER.extra_layer_storage)

[[],[],[]]

EXTRA_LAYER.remove_layers(1)

print(EXTRA_LAYER.extra_layer_storage)

[[],[]]

EXTRA_LAYER.display_layers()

[]
[]

EXTRA_LAYER.display_layers_horizontal()

[][]

'''



from typing import AbstractSet, Any
from abc import ABC , abstractmethod

class d_display:
          def store_(self,should_store_: bool,item_to_store: Any):
                    store_dict = {
                              True:item_to_store
                    }
                    return store_dict.get(should_store_)

class my_class(ABC):
          @abstractmethod
          def save(self):
                    pass
          
          @abstractmethod
          def process(self):
                    pass
          
          @abstractmethod
          def display(self):
                    pass
          
d_management_display = d_display()

'''
The d_management_display object displays an item depending on the boolean entered.
The my_class abstract class can be used to make custom classes based on the methods save_ , process and display.
my_class indicates that it is your class that you coded.

def do_(my_class):
          def save(self,something):
                    #some code
                    
          def process(self,something):
                    #some code
          
          def display(self,something):
                    #some code

value = 1
t = False

if value == 1:
          t = True
          d_management_display.store_(t,value)

'''


from dataclasses import dataclass


          
class stilix_list:
          def add_styles(self,reciever_list: list,sender_list: list):
                    for item in sender_list:
                              reciever_list.append(item)
                              
          def remove_styles(self,remove_list: list,items_to_remove: list):
                    for item in items_to_remove:
                              if item in remove_list:
                                        remove_list.remove(item) 
                                        
          def display_all(self,list_to_display_all: list):
                    for item in list_to_display_all:
                              print(item)
          
          def display_all_horizontal(self,list_to_display_all: list):
                    for item in list_to_display_all:
                              print(item,end="")

'''
The STILIX_LIST object can be used to perform simple operations on lists.The add_styles method can be used to add the desired items in the sender list to the reciever list.This is a way of adding stuff to lists with the
STILIX_LIST object.The remove_styles method can be used to remove the desired styles from the list.STILIX_LIST can also handle
when it comes to list output.The display all method can be used to display all the stuff from the list.The display_all_horizontol method can be used to display all of the items in the list in a horizontal way.

a = ["circle","square"]
STILIX_LIST.add_styles(a,["rectangle","oval"])
a then becomes ["circle","square","rectangle","oval"]
STILIX_LIST.remove_styles(a,["rectangle","oval"])
a then becomes ["circle","square"]
STILIX_LIST.display_all(a)
then comes the output
circle
square
a = ["circle ","square "]
STILIX_LIST.display_all_horizontal(a)
then comes the output
circle square
'''
@dataclass
class stilix_list_count:
          value: int
          def list_length(self,list_: list):
                    for item in list_:
                              self.value += 1
                    return self.value
          
          def list_count(self,list_: list,desired_counts: list):
                    for item in list_:
                              if item in desired_counts:
                                        self.value += 1
                    return self.value
          
          def reveal_item_indices(self,list_containing_item: list,items: list):
                    for item in items:
                              return list_containing_item.index(item)
          
'''
When it comes to list info the STILIX_LIST_COUNT object can handle that.Printing the list_length of the list can return the lists length.Printing the list_count of the desired items
in the list can return the amount of the desired items in the list.Printing the reveal_item_indices of the desired items in the list can return the indices of the desired items
in the list.
a = [5,6,6,7]
print(STILIX_LIST_COUNT.list_length(a))
4
print(STILIX_LIST_COUNT.list_count(a,[6]))
2
print(STILIX_LIST_COUNT.reveal_item_indices(a,[5,7]))
[0,3]
'''
          
STILIX_LIST = stilix_list()    

STILIX_LIST_COUNT = stilix_list_count(0)

@dataclass
class stilix:
          style: str = " * "
          def split_(self,storage: list,storage_to: list):
                    STILIX_LIST.add_styles(storage_to,storage)
                    
          def insert_style(self,storage: list):
                    value = 1
                    while value < STILIX_LIST_COUNT.list_length(storage):
                              storage.insert(value,self.style)
                              value += 2
                               
          def change_style(self,desired_style: str):
                    self.style = f" {desired_style} "

STILIX = stilix([])

'''
The STILIX object can be used for further list output.The insert_style method can be used to insert the * symbol between the stuff in the list.Now all you can do is use one
of the list output methods to generate a nice list output.However inserting the * symbol into the list can cause problems with the indices of the other stuff in the list.
You can use the split_ method to have two same lists.One list can be used to process the stuff , another list can be used for inserting the * symbol into it and to be the output.
Dont like the default * symbol, you can use the change_style method to switch the * symbol to your desired symbol.

a = ["circle","rectangle"]
STILIX.insert_style(a)
STILIX_LIST.display_all_horizontal(a)

circle * square

a = ["circle","square"]
STILIX.change_style("//")
STILIX.insert_style(a)
STILIX_LIST.display_all_horizontal(a)

circle // square

a , b= ["m","e"] , []
STILIX.split_(a,b)
STILIX.insert_style(a)
STILIX_LIST.display_all_horizontal(a)
print(f"{b[0]}{b[1]})

m * e
me

'''


from dataclasses import dataclass
from Stilix import STILIX_LIST , STILIX_LIST_COUNT
@dataclass
class empty_space:
          list_: list
          def check_reset(self,list_to_check_reset: list):
                    dict_check = {
                              0:True
                    }
                    print(dict_check.get(STILIX_LIST_COUNT.list_length(list_to_check_reset)))
                    
empty_list=empty_space([])

'''
The empty_list object contains an empty list which can be used on anything.
The check_reset mehod of the empty list object checks if the desired list is empty.

empty_list.list_ = ["a"]

empty_list.check_reset(empty_list.list_)

False

w = []

empty_list.check_reset(w)

True
'''

class change_data:
          def normal_save(self,thing_to_save: list,save_on: list):
                    save_on.append(thing_to_save)
                    
          def tuple_save(self,thing_too_tup: list,save_tup_on_thing: list):
                    thing_too_tup=tuple(thing_too_tup)
                    save_tup_on_thing.append(thing_too_tup)
                    thing_too_tup=list(thing_too_tup)
                    
          def set_save(self,thing_to_list: list,save_list_on: list):
                    thing_to_list=set(thing_to_list)
                    save_list_on.append(thing_to_list)
                    thing_to_list=list(thing_to_list)

data_change=change_data()

'''
The data_change object saves a list as a different data structure like tuples or sets in a list.
The data_change.normal_save method can be used to just save a list in another list without changing it.
The data_change.tuple_save method can be used to save a list as a tuple in another list.
The data_change.set_save method can be used to save a list as a set in another list.

b = []
a = []
data_change.normal_save(a,b)
print(b)

[[]]

data_change.tuple_save(a,b)
print(b)

[()]

data_change.set_save(a,b)
print(b)

[{}]

'''